# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/lead/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\Lead\\": "packages/litecms/lead/src",
            "Litecms\\Lead\\Seeders\\": "packages/litecms/lead/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\Lead\Providers\LeadServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Lead'  => Litecms\Lead\Facades\Lead::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\Lead\\Seeders\\LeadTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\Lead\Providers\LeadServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\Lead\Providers\LeadServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\Lead\Providers\LeadServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/lead/{modulename}

**User**

    http://path-to-route-folder/user/lead/{modulename}

**Public**

    http://path-to-route-folder/leads


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/lead/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/lead/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/lead/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/lead/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/lead/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/lead/{modulename}/{slug}
    METHOD: GET